==> apeman-commons-logging-1.3.3.tgz: package/lib/apeman_ui_logger.js <==
/**
 * Create a logger for apeman ui package.
 * @memberof module:apeman-commons-logging/lib
 * @function apemanUiLogger
 * @param {object} [options] - Optional settings.
 * @param {string} [options.name] - Name of log.
 * @param {boolean} [options.verbose] - Should emit verbose.
 * @returns {ConsoleLogger} - A logger instance.
 */

"use strict";

var ConsoleLogger = require('./console_logger'),
    MessageFormatter = require('./message_formatter'),
    util = require('util');

/** @lends apemanUiLogger */
function apemanUiLogger(options) {
    options = options || {};
    var name = options.name || 'apeman-ui',
        verbose = !!options.verbose;
    return new ConsoleLogger({
        verbose: verbose,
        PREFIX: util.format('[%s] ', name),
        /**
         * Print about ui start.
         */
        printUiStart: function () {
            var s = this;
            s.info('Start UI building..');
        },
        /**
         * Print about ui done.
         */
        printUiDone: function () {
            var s = this;
            s.info('..building UI done!');
        },
        /**
         * Print about ui fail.
         * @param {Error} err
         */
        printUiFailed: function (err) {
            var s = this;
            s.error(err.stack || err.msg || err);
        },
        /**
         * Print about config.
         * @param {string} name - Name of log.
         * @param {object} config - Config to log.
         */
        printConfig: function (name, config) {
            var s = this;
            s.trace("%s", config);
        }
    });
}

module.exports = apemanUiLogger;

==> apeman-commons-logging-1.3.4.tgz: package/lib/apeman_ui_logger.js <==
/**
 * Create a logger for apeman ui package.
 * @memberof module:apeman-commons-logging/lib
 * @function apemanUiLogger
 * @param {object} [options] - Optional settings.
 * @param {string} [options.name] - Name of log.
 * @param {boolean} [options.verbose] - Should emit verbose.
 * @returns {ConsoleLogger} - A logger instance.
 */

"use strict";

var ConsoleLogger = require('./console_logger'),
    MessageFormatter = require('./message_formatter'),
    util = require('util');

/** @lends apemanUiLogger */
function apemanUiLogger(options) {
    options = options || {};
    var name = options.name || 'apeman-ui',
        verbose = !!options.verbose;
    return new ConsoleLogger({
        verbose: verbose,
        PREFIX: util.format('[%s] ', name),
        /**
         * Print about ui start.
         */
        printUiStart: function () {
            var s = this;
            s.info('Start UI building..');
        },
        /**
         * Print about ui done.
         */
        printUiDone: function () {
            var s = this;
            s.info('..building UI done!');
        },
        /**
         * Print about ui fail.
         * @param {Error} err
         */
        printUiFailed: function (err) {
            var s = this;
            s.error(err.stack || err.msg || err);
        },
        /**
         * Print about config.
         * @param {object} config - Config to log.
         */
        printConfig: function (config) {
            var s = this;
            s.trace("%s", config);
        }
    });
}

module.exports = apemanUiLogger;
